@@ -23,6 +23,7 @@ adm
 admin
 administration
 administrator
+ads
 adult
 advertising
 affiliate
@@ -34,6 +35,7 @@ android
 anon
 anonymous
 anus
+apache
 api
 app
 apps
@@ -41,8 +43,10 @@ archive
 arse
 ass
 atom
+audio
 auth
 authentication
+authority
 autoconfig
 avatar
 backup
@@ -72,11 +76,14 @@ bum
 business
 butt
 buttplug
+ca
 cache
 cadastro
 calendar
 campaign
 careers
+ceo
+cert
 cgi
 chat
 client
@@ -85,18 +92,22 @@ clitoris
 cock
 code
 comercial
+commerce
 compare
 compras
 config
 connect
+console
 contact
 contest
 coon
 copyright
 crap
 create
+crt
 css
 cunt
+daemon
 damn
 dashboard
 data
@@ -107,10 +118,12 @@ design
 designer
 dev
 devel
+devs
 dick
 dildo
 dir
 directory
+dns
 doc
 docs
 domain
@@ -137,6 +150,7 @@ fellate
 fellatio
 file
 files
+firewall
 flange
 flog
 follow
@@ -168,6 +182,7 @@ hosting
 hostmaster
 hostname
 hpg
+hr
 html
 http
 httpd
@@ -185,6 +200,8 @@ intranet
 intro
 introduction
 invite
+invoice
+invoices
 ipad
 iphone
 irc
@@ -202,10 +219,14 @@ knob
 knobend
 knowledgebase
 labia
+licence
+license
 licensing
 links
 list
+list-request
 lists
+live
 lmao
 lmfao
 localdomain
@@ -224,6 +245,7 @@ mail5
 mailer
 mailer-daemon
 mailing
+maintainer
 manager
 marketing
 master
@@ -237,6 +259,10 @@ mine
 mis
 mob
 mobile
+mod
+moderator
+moderators
+mods
 motherfucker
 movie
 movies
@@ -256,6 +282,7 @@ network
 new
 news
 newsletter
+nginx
 nick
 nickname
 nigga
@@ -271,10 +298,13 @@ ns1
 ns2
 ns3
 ns4
+ntp
+null
 old
 omg
 online
 operator
+operators
 order
 orders
 packer
@@ -282,7 +312,10 @@ page
 pager
 pages
 panel
+passwd
 password
+pay
+payment
 payments
 penis
 perl
@@ -304,20 +337,26 @@ post
 postfix
 postmaster
 posts
+pr
 pricing
 prick
+printer
 privacy
 profile
 project
 projects
 promo
+promotion
+proxy
 pub
 pube
 public
+purchase
 pussy
 python
 queer
 random
+redir
 refund
 refunds
 register
@@ -339,6 +378,7 @@ search
 secure
 security
 send
+sendmail
 service
 services
 setting
@@ -359,7 +399,9 @@ smtp
 soporte
 spunk
 sql
+squid
 ssh
+ssl
 ssladmin
 ssladministrator
 sslwebmaster
@@ -372,12 +414,19 @@ stats
 status
 store
 stores
+stream
 subdomain
 subscribe
+sudo
+superuser
 suporte
 support
 survey
+sync
+sys
 sysadmin
+syslog
+sysop
 system
 tablet
 tablets
@@ -386,6 +435,7 @@ task
 tasks
 tech
 telnet
+terminal
 terms
 test
 test1
@@ -411,6 +461,7 @@ url
 usage
 usenet
 user
+userdb
 username
 users
 usuario
@@ -426,6 +477,7 @@ webmail
 webmaster
 website
 websites
+wheel
 whore
 win
 workshop
@@ -453,6 +505,7 @@ yourusername
 """
 
 
+
 def get_reserved_wordlist():
     return set(_d.splitlines())
 
